pub struct BudgetAllocation {
pub system: usize,
pub critical: usize,
pub primary: usize,
pub supporting: usize,
pub reference: usize,
}Expand description
Divides a total token budget across context zones.
Fields
system: usizeSystem zone
critical: usizeCritical zone
primary: usizePrimary zone
supporting: usizeSupporting zone
reference: usizeReference zone
Implementations
Sourceimpl BudgetAllocation
impl BudgetAllocation
Sourcepub fn from_total_with_config(total: usize, config: &ZoneBudgetConfig) -> Self
pub fn from_total_with_config(total: usize, config: &ZoneBudgetConfig) -> Self
Allocate a total budget across zones with the given percentages.
Sourcepub fn from_total(total: usize) -> Self
pub fn from_total(total: usize) -> Self
Allocate a total budget across zones with default percentages.